"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CreateIndexesTaskRunner = void 0;
var _CreateElasticsearchIndexTaskPlugin = require("./CreateElasticsearchIndexTaskPlugin");
class CreateIndexesTaskRunner {
  constructor(manager, indexManager) {
    this.manager = manager;
    this.indexManager = indexManager;
  }
  async execute(matching, done) {
    const plugins = this.manager.context.plugins.byType(_CreateElasticsearchIndexTaskPlugin.CreateElasticsearchIndexTaskPlugin.type);
    if (plugins.length === 0) {
      return this.manager.response.done("No index plugins found.");
    }
    const indexes = [];
    const tenants = await this.manager.context.tenancy.listTenants();
    for (const tenant of tenants) {
      const locales = await this.manager.context.i18n.getLocales();
      for (const locale of locales) {
        for (const plugin of plugins) {
          const results = await plugin.getIndexList({
            context: this.manager.context,
            tenant: tenant.id,
            locale: locale.code
          });
          indexes.push(...results);
        }
      }
    }
    if (indexes.length === 0) {
      return this.manager.response.done("No indexes found.");
    }
    const isIndexAllowed = index => {
      if (typeof matching !== "string" || !matching) {
        return true;
      }
      return index.includes(matching);
    };
    for (const {
      index,
      settings
    } of indexes) {
      if (this.manager.isAborted()) {
        return this.manager.response.aborted();
      } else if (this.manager.isCloseToTimeout()) {
        return this.manager.response.continue({
          done
        });
      }
      try {
        if (done.includes(index)) {
          continue;
        } else if (isIndexAllowed(index) === false) {
          continue;
        }
        const exists = await this.indexManager.indexExists(index);
        if (exists) {
          continue;
        }
        done.push(index);
        await this.indexManager.createIndex(index, settings);
        await this.manager.store.addInfoLog({
          message: `Index "${index}" created.`,
          data: {
            index
          }
        });
      } catch (ex) {
        await this.manager.store.addErrorLog({
          message: `Failed to create index "${index}".`,
          error: ex
        });
      }
    }
    return this.manager.response.done("Indexes created.", {
      done
    });
  }
}
exports.CreateIndexesTaskRunner = CreateIndexesTaskRunner;

//# sourceMappingURL=CreateIndexesTaskRunner.js.map